/*
This file is part of Adapa (Automatic DAta PArallelism)
Copyright (C) 2009  Pedro Ribeiro (CRACS & INESC-Porto LA, U. Porto)

Adapa is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License version 3, as
published by the Free Software Foundation.

Adapa is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Adapa.  If not, see <http://www.gnu.org/licenses/>.
*/
 
#include "Error.h"

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>

// --------------------------------------

/* Output an error message and exit program */
void Error::output(char *fmt, ...) {
  va_list ap;
  char *s;
  int d;
  double f;
  fprintf(stderr, "ERROR: ");

  va_start(ap, fmt);
  while (*fmt)
    switch(*fmt++) {
    case 's':           /* string */
      s = va_arg(ap, char *);
      fprintf(stderr, "%s", s);
      break;
    case 'd':           /* int */
      d = va_arg(ap, int);
      fprintf(stderr, "%d", d);
      break;
    case 'f':           /* double */
      f = va_arg(ap, double);
      fprintf(stderr, "%.3lf", f);
      break;
    }
  va_end(ap);
  
  fprintf(stderr, "\n");
  exit(1);
}

// --------------------------------------

/* Output an error message about a specific paramater */
void Error::parameterInvalid(Parameters &p, string s) {
  fprintf(stderr, "ERROR: Argument %s=\"%s\" is invalid!\n",
	  s.c_str(), p.arg[s].c_str());
  exit(1);
}
